@@ -1,9 +1,10 @@
+
 #' Add a Job
 #' 
-#' Inform RStudio's Jobs pane that a job has been added.
+#' Inform RStudio's Background Jobs pane that a job has been added.
 #' 
 #' 
-#' @param name The job's name.
+#' @param name The background job's name.
 #' @param status The initial status text for the job; optional.
 #' @param progressUnits The integer number of units of work in the job; for
 #' example, \code{100L} if the job's progress is expressed in percentages. Use
@@ -11,8 +12,8 @@
 #' @param actions A list of actions that can be performed on the job (see
 #' Actions).
 #' @param running Whether the job is currently running.
-#' @param autoRemove Whether to remove the job from the Jobs pane when it's
-#' complete.
+#' @param autoRemove Whether to remove the job from the Background Jobs pane 
+#' when it's complete.
 #' @param show Whether to show the job in the Jobs pane.
 #' @return An ID representing the newly added job, used as a handle to provide
 #' further updates of the job's status.
@@ -23,17 +24,18 @@
 #' ... })}. The function will be passed a parameter named \code{id} with the
 #' job ID that invoked it.
 #' 
-#' There are two special action names: \describe{ \item{stop}{If there is an
+#' There are three special action names: \describe{ \item{stop}{If there is an
 #' action named \code{stop}, then the job will have a Stop button in in the
 #' Jobs pane, and pressing that button will invoke the \code{stop} action.}
 #' \item{info}{If there is an action named \code{info}, then the job will have
-#' an informational link in the Jobs pane rather than an output display, and
-#' clicking the link will invoke the \code{info} action.} }
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobRemove}()},
-#' \code{\link{jobRunScript}()}, \code{\link{jobSetProgress}()},
-#' \code{\link{jobSetState}()}, \code{\link{jobSetStatus}()}
-#' @export jobAdd
+#' an informational link in the Background Jobs pane rather than an output display, 
+#' and clicking the link will invoke the \code{info} action.}
+#' \item{replay}{If there is an action named \code{replay}, then the job will
+#' have a Replay button that displays when the job has finished running. Clicking
+#' the button will invoke the \code{replay} action.}}
+#' 
+#' @family jobs
+#' @export
 jobAdd <- function(name, status = "", progressUnits = 0L, actions = NULL, running = FALSE,
                    autoRemove = TRUE, show = TRUE) {
     callFun("addJob", name          = name,
@@ -47,81 +49,78 @@ jobAdd <- function(name, status = "", progressUnits = 0L, actions = NULL, runnin
 
 
 
-#' Remove a Job
-#' 
-#' Remove a job from RStudio's Jobs pane.
+#' Remove a Background Job
 #' 
+#' Remove a background job from RStudio's Background Jobs pane.
 #' 
 #' @param job The ID of the job to remove.
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRunScript}()}, \code{\link{jobSetProgress}()},
-#' \code{\link{jobSetState}()}, \code{\link{jobSetStatus}()}
-#' @export jobRemove
+#' 
+#' @family jobs
+#' @export
 jobRemove <- function(job) {
     callFun("removeJob", job = job)
 }
 
 
 
-#' Set Job Progress
-#' 
-#' Updates the progress for a job.
+#' Set Background Job Progress
 #' 
+#' Updates the progress for a background job.
 #' 
 #' @param job The ID of the job to set progress for.
 #' @param units The integer number of total units of work completed so far.
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobRunScript}()},
-#' \code{\link{jobSetState}()}, \code{\link{jobSetStatus}()}
-#' @export jobSetProgress
+#' 
+#' @family jobs
+#' @export
 jobSetProgress <- function(job, units) {
     callFun("setJobProgress", job = job, units = units)
 }
 
 
 
-#' Add Job Progress
+#' Add Background Job Progress
 #' 
-#' Adds incremental progress units to a job.
+#' Adds incremental progress units to a background job.
 #' 
 #' 
 #' @param job The ID of the job to update progress for.
 #' @param units The integer number of new progress units completed.
-#' @seealso Other jobs: \code{\link{jobAddOutput}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobRunScript}()},
-#' \code{\link{jobSetProgress}()}, \code{\link{jobSetState}()},
-#' \code{\link{jobSetStatus}()}
-#' @export jobAddProgress
+#'
+#' @family jobs
+#' @export
 jobAddProgress <- function(job, units) {
     callFun("addJobProgress", job = job, units = units)
 }
 
 
 
-#' Set Job Status
+#' Set Background Job Status
 #' 
-#' Update a job's informational status text.
+#' Update a background job's informational status text.
 #' 
 #' 
 #' @param job The ID of the job to update.
 #' @param status Text describing job's new status.
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobRunScript}()},
-#' \code{\link{jobSetProgress}()}, \code{\link{jobSetState}()}
-#' @export jobSetStatus
+#'
+#' @family jobs
+#' @export
 jobSetStatus <- function(job, status) {
     callFun("setJobStatus", job = job, status = status)
 }
 
-
-
-
-#' Set Job State
+#' Get Background Job State
 #' 
-#' Changes the state of a job.
+#' @param job The ID of the job.
+#' 
+#' @family jobs
+#' @export
+jobGetState <- function(job) {
+    callFun("getJobState", job = job)
+}
+
+#' Set Background Job State
+#' 
+#' Changes the state of a background job.
 #' 
 #' 
 #' @param job The ID of the job on which to change state.
@@ -132,11 +131,9 @@ jobSetStatus <- function(job, status) {
 #' waiting to run.} \item{running}{The job is actively running.}
 #' \item{succeeded}{The job has finished successfully.} \item{cancelled}{The
 #' job was cancelled.} \item{failed}{The job finished but did not succeed.} }
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobRunScript}()},
-#' \code{\link{jobSetProgress}()}, \code{\link{jobSetStatus}()}
-#' @export jobSetState
+#' 
+#' @family jobs
+#' @export
 jobSetState <- function(job, state = c("idle", "running", "succeeded", "cancelled", "failed")) {
     callFun("setJobState", job = job, state = state)
 }
@@ -144,19 +141,17 @@ jobSetState <- function(job, state = c("idle", "running", "succeeded", "cancelle
 
 
 
-#' Add Job Output
+#' Add Background Job Output
 #' 
-#' Adds text output to a job.
+#' Adds text output to a background job.
 #' 
 #' 
 #' @param job The ID of the job that has emitted text.
 #' @param output The text output emitted by the job.
 #' @param error Whether the output represents an error.
-#' @seealso Other jobs: \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobRunScript}()},
-#' \code{\link{jobSetProgress}()}, \code{\link{jobSetState}()},
-#' \code{\link{jobSetStatus}()}
-#' @export jobAddOutput
+#'
+#' @family jobs
+#' @export
 jobAddOutput <- function(job, output, error = FALSE) {
     callFun("addJobOutput", job = job, output = output, error = error)
 }
@@ -164,7 +159,7 @@ jobAddOutput <- function(job, output, error = FALSE) {
 
 
 
-#' Run R Script As Job
+#' Run R Script As Background Job
 #' 
 #' Starts an R script as a background job.
 #' 
@@ -180,11 +175,9 @@ jobAddOutput <- function(job, output, error = FALSE) {
 #' objects created by the job. Use \code{""} (the default) to skip export,
 #' \code{"R_GlobalEnv"}` to export to the global environment, or the name of an
 #' environment object to create an object with that name.
-#' @seealso Other jobs: \code{\link{jobAddOutput}()},
-#' \code{\link{jobAddProgress}()}, \code{\link{jobAdd}()},
-#' \code{\link{jobRemove}()}, \code{\link{jobSetProgress}()},
-#' \code{\link{jobSetState}()}, \code{\link{jobSetStatus}()}
-#' @export jobRunScript
+#'
+#' @family jobs
+#' @export
 jobRunScript <- function(path, name = NULL, encoding = "unknown", workingDir = NULL,
                          importEnv = FALSE, exportEnv = "") {
     path <- normalizePath(path, winslash = "/", mustWork = TRUE)
@@ -195,3 +188,13 @@ jobRunScript <- function(path, name = NULL, encoding = "unknown", workingDir = N
                             importEnv  = importEnv,
                             exportEnv  = exportEnv)
 }
+
+#' List Background Jobs
+#' 
+#' List any registered background jobs.
+#' 
+#' @family jobs
+#' @export
+jobList <- function() {
+    callFun("listJobs")
+}
